package net.wanji.opt.cache;

import lombok.extern.slf4j.Slf4j;
import net.wanji.databus.dao.mapper.CrossInfoMapper;
import net.wanji.databus.po.CrossInfoPO;
import net.wanji.databus.vo.CrossInfoVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author duanruiming
 * @date 2023/03/14 10:42
 */
@Component
@Slf4j
public class CrossInfoCache implements CommandLineRunner {

    @Autowired
    private CrossInfoMapper crossInfoMapper;

    private static final List<CrossInfoPO> crossInfoList = new ArrayList<>();

    /**
     * 获取所有路口信息
     *
     * @return
     */
    public List<CrossInfoPO> getCrossInfoCache() {
        return crossInfoList;
    }

    /**
     * 获取所有信控路口的路口编号
     *
     * @return
     */
    public List<String> getIsSignalCrossIdList() {
        List<String> isSignalCrossIdList = crossInfoList.stream().filter(crossInfoPO -> crossInfoPO.getIsSignal() == 1).map(CrossInfoPO::getId).collect(Collectors.toList());
        return isSignalCrossIdList;
    }

    @Override
    public void run(String... args) throws Exception {
        init();
    }

    public void init () {
        List<CrossInfoPO> crossInfoPOS = crossInfoMapper.selectAll(new CrossInfoVO());
        if (!CollectionUtils.isEmpty(crossInfoPOS)) {
            crossInfoList.addAll(crossInfoPOS);
        }
    }
}
