package net.wanji.opt.service.impl;

import net.wanji.common.framework.Constants;
import net.wanji.common.utils.tool.BeanListUtils;
import net.wanji.opt.dao.mapper.CrossPhaseLightsMapper;
import net.wanji.opt.dao.mapper.CrossPhaseMapper;
import net.wanji.opt.dto.CrossLightsDTO;
import net.wanji.opt.dto.CrossPhaseDTO;
import net.wanji.opt.po.base.CrossPhaseLightsPO;
import net.wanji.opt.po.base.CrossPhasePO;
import net.wanji.opt.service.CrossLightsService;
import net.wanji.opt.service.CrossPhaseService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author hfx
 * @date 2023/1/13 10:10
 * @desc 相位接口服务实现
 */
@Service
public class CrossPhaseServiceImpl implements CrossPhaseService {

    @Resource
    CrossPhaseMapper crossPhaseMapper;

    @Resource
    CrossPhaseLightsMapper phaseLightsMapper;

    @Resource
    CrossLightsService crossLightsService;


    @Override
    public List<CrossPhaseDTO> listCrossPhase() {

        // 获取相位信息
        List<CrossPhasePO> crossPhasePOList = crossPhaseMapper.listCrossPhase("", Constants.SystemParam.NULL_INT);
        return BeanListUtils.populateList(crossPhasePOList, new ArrayList<>(), CrossPhaseDTO.class);
    }

    @Override
    public List<CrossPhaseDTO> listPhaseDetails() {

        // 获取相位信息
        List<CrossPhaseDTO> phaseDTOList = listCrossPhase();
        if(phaseDTOList.isEmpty()) {
            return phaseDTOList;
        }

        // 获取相位灯组信息
        Map<Integer, List<CrossLightsDTO>> phaseLightsMap = listPhaseLights();
        for(CrossPhaseDTO phase : phaseDTOList) {
            phase.setLightsInfos(phaseLightsMap.get(phase.getId()));
        }
        return phaseDTOList;
    }

    /**
     * 获取相位灯组信息
     * @return
     */
    private Map<Integer, List<CrossLightsDTO>> listPhaseLights() {

        Map<Integer, List<CrossLightsDTO>> phaseLightsMap = new HashMap<>();
        // 获取相位灯组信息
        List<CrossPhaseLightsPO> phaseLightsPOList = phaseLightsMapper.listCrossPhaseLights();
        if(phaseLightsPOList.isEmpty()) {
            return phaseLightsMap;
        }
        // 获取灯组详情信息
        List<CrossLightsDTO> lightsDTOList = crossLightsService.listLightsDetails();
        // 处理灯组数据，封装成map：key是相位ID，value灯组集合
        Map<Integer, CrossLightsDTO> lightsMap = lightsDTOList.stream().collect(Collectors.toMap(e -> e.getId(), e -> e));

        Integer phaseId;
        for(CrossPhaseLightsPO po : phaseLightsPOList) {

            phaseId = po.getPhaseId();
            if(phaseLightsMap.containsKey(phaseId)) {
                lightsDTOList = phaseLightsMap.get(phaseId);
            } else {
                lightsDTOList = new ArrayList<>();
                phaseLightsMap.put(phaseId, lightsDTOList);
            }
            lightsDTOList.add(lightsMap.get(po.getLightsId()));
        }
        return phaseLightsMap;
    }

}
